@@ -3,5 +3,5 @@ from .feeds import LatestBlogEntries
 
 urlpatterns = patterns('',
     url(r'^latest/entries/$', LatestBlogEntries(), name='blog-entry-feed'),
-    (r'^', include('djangoandablog.urls', namespace='andablog')),
+    (r'^', include('andablog.urls', namespace='andablog')),
 )
